gchecky.gxml.ID

Package gchecky :: Module gxml :: Class ID |
[hide private]
[frames] | no frames]

# Class ID

source code

    object --+
             |
         Field --+
                 |
            String --+
                     |
                    ID

Instance Methods | [hide private]
validate(self, data) | source code
Inherited from `String`: `__init__`, `data2str`, `str2data` Inherited from `Field`: `__repr__`, `create_node_for_path`, `get_any_node_for_path`, `get_initial_value`, `get_nodes_for_path`, `get_one_node_for_path`, `load`, `save` Inherited from `Field` (private): `_traits` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `Field`: `deconstruct_path`, `reconstruct_path`

Class Variables | [hide private]
| empty = `False` weither the field value could be empty (an empty XML tag)

Instance Variables | [hide private]
Inherited from `Field`: `default`, `path`, `required`, `save_node_and_xml`, `values`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### validate(self, data) | source code
Decorators: `@apply_parent_validation(String, error_prefix= "ID: ")` Overrides: String.validate